@@ -1,11 +1,9 @@
-import logging
 import sys
 import time
 from threading import Event, Thread
 
 from .exceptions import NetworkError
-
-logger = logging.getLogger("smalld")
+from .logger import logger
 
 
 def add_standard_listeners(smalld):
@@ -28,7 +26,7 @@ class SequenceNumber:
         self.smalld = smalld
         self.number = None
 
-        smalld.on_gateway_payload()(self.on_payload)
+        smalld.on_gateway_payload(self.on_payload)
 
     def on_payload(self, data):
         if data.s:
@@ -41,11 +39,11 @@ class Identify:
         self.sequence = sequence
         self.session_id = None
 
-        smalld.on_ready()(self.on_ready)
-        smalld.on_resumed()(self.on_resumed)
-        smalld.on_gateway_payload(op=OP_HELLO)(self.on_hello)
-        smalld.on_gateway_payload(op=OP_INVALID_SESSION)(self.on_invalid_session)
-        smalld.on_gateway_payload(op=OP_RECONNECT)(self.on_reconnect)
+        smalld.on_ready(self.on_ready)
+        smalld.on_resumed(self.on_resumed)
+        smalld.on_gateway_payload(self.on_hello, op=OP_HELLO)
+        smalld.on_gateway_payload(self.on_invalid_session, op=OP_INVALID_SESSION)
+        smalld.on_gateway_payload(self.on_reconnect, op=OP_RECONNECT)
 
     def on_ready(self, data):
         logger.info("Ready.")
@@ -61,11 +59,13 @@ class Identify:
             self.identify()
 
     def on_invalid_session(self, data):
+        logger.info("Invalid session.")
         self.session_id = None
         time.sleep(2)
         self.identify()
 
     def on_reconnect(self, data):
+        logger.info("Discord requested reconnect...")
         self.smalld.reconnect()
 
     def identify(self):
@@ -82,6 +82,7 @@ class Identify:
                     },
                     "compress": False,
                     "intents": self.smalld.intents.value,
+                    "shard": self.smalld.shard,
                 },
             }
         )
@@ -108,12 +109,12 @@ class Heartbeat:
         self.heartbeat_interval = None
         self.received_ack = Event()
 
-        smalld.on_gateway_payload(op=OP_HELLO)(self.on_hello)
-        smalld.on_gateway_payload(op=OP_HEARTBEAT)(self.on_heartbeat)
-        smalld.on_gateway_payload(op=OP_HEARTBEAT_ACK)(self.on_heartbeat_ack)
+        smalld.on_gateway_payload(self.on_hello, op=OP_HELLO)
+        smalld.on_gateway_payload(self.on_heartbeat, op=OP_HEARTBEAT)
+        smalld.on_gateway_payload(self.on_heartbeat_ack, op=OP_HEARTBEAT_ACK)
 
     def on_hello(self, data):
-        self.heartbeat_interval = data.d.heartbeat_interval
+        self.heartbeat_interval = data.d.heartbeat_interval / 1000
 
         if not self.thread or not self.thread.is_alive():
             self.thread = Thread(target=self.run_heartbeat_loop)
@@ -126,19 +127,19 @@ class Heartbeat:
         self.received_ack.set()
 
     def run_heartbeat_loop(self):
-        interval = self.heartbeat_interval / 1000
-        time.sleep(interval)
+        time.sleep(self.heartbeat_interval)
         while not self.smalld.closed:
             try:
                 self.send_heartbeat()
             except NetworkError:
                 continue
             finally:
-                time.sleep(interval)
+                time.sleep(self.heartbeat_interval)
 
             if self.received_ack.is_set():
                 self.received_ack.clear()
             else:
+                logger.info("No heartbeat ack. Reconnecting...")
                 self.smalld.reconnect()
                 break
 
